#!/usr/bin/env ruby
#based on http://www.tldp.org/HOWTO/NCURSES-Programming-HOWTO/scanw.html
require 'ncurses'
msg = "Enter a string:"



def create_newwin(height, width, starty, startx)
	#create window object
	local_win = Ncurses.newwin(height, width, starty, startx)

	#add border
	Ncurses.box(local_win, 0 , 0)

	#add text in the window
	Ncurses.mvwaddstr(local_win,1,1,"F1 to exit")

	#refresh its display
	Ncurses.wrefresh(local_win)
	return local_win
end

def destroy_win(local_win)
    # box(local_win, ' ', ' '); : This won't produce the desired
    # result of erasing the window. It will leave it's four corners 
    # and so an ugly remnant of window. 
	# we need to pass the character's code, hence the use of []
	Ncurses.wborder(local_win, ' '[0], ' '[0], ' '[0],' '[0],' '[0],' '[0],' '[0],' '[0])
	Ncurses.wrefresh(local_win)
	Ncurses.delwin(local_win)
end





begin
	# init variables
	height = 3
	width = 15
	
	#getmaxyx takes empty arrays as argument
	rows=cols=[]
	
	Ncurses.initscr
	#Get number of rows and columns. Both are arrays, that seem equals to me... 
	#(first element=number of rows, second element =number of columns)

	Ncurses.stdscr.getmaxyx(rows,cols)
	
	Ncurses.stdscr.keypad(true)
	Ncurses.cbreak
	
	starty = (rows[0]-height)/2
	startx = (cols[1]-width )/2

	#start color functionality
	Ncurses.start_color
	#Initialise the color pair number 1
	Ncurses.init_pair(1, Ncurses::COLOR_CYAN, Ncurses::COLOR_BLACK)
	#switch color pair 1 on
	Ncurses.attron(Ncurses::COLOR_PAIR(1));
	Ncurses.printw("Press F1 to exit")
	Ncurses.refresh
	#switch color pair 1 off
	Ncurses.attroff(Ncurses::COLOR_PAIR(1));

	my_win = create_newwin(height, width, starty, startx)

	while  (ch=Ncurses.getch)!=Ncurses::KEY_F1
		case ch
			when Ncurses::KEY_LEFT
				next if startx-1<0
				destroy_win(my_win)
				my_win = create_newwin(height, width, starty,startx-=1)
			when Ncurses::KEY_RIGHT
				next if startx+1>cols[1]
				destroy_win(my_win)
				my_win = create_newwin(height, width, starty,startx+=1)
			when Ncurses::KEY_UP
				next if starty-1<0
				destroy_win(my_win)
				my_win = create_newwin(height, width, starty-=1,startx)
			when Ncurses::KEY_DOWN
				next if starty+1>rows[0]
				destroy_win(my_win)
				my_win = create_newwin(height, width, starty+=1,startx)
		end
	end
	
ensure
	Ncurses.endwin
end
